==> geshi_1.0.7.14.orig.tar.gz: geshi/geshi/text.php <==
<?php
/*************************************************************************************
 * text.php
 * --------
 * Author: Sean Hanna (smokingrope@gmail.com)
 * Copyright: (c) 2006 Sean Hanna 
 * Release Version: 1.0.7.14
 * CVS Revision Version: $Revision: 1.2.2.5 $
 * Date Started: 04/23/2006
 * Last Modified: $Date: 2006/09/14 09:44:46 $
 *
 * Standard Text File (No Syntax Highlighting).
 *
 * CHANGES
 * -------
 * 04/23/2006 (0.5.0)
 *  -  Syntax File Created
 *
 * 04/27/2006 (1.0.0)
 * - Documentation Cleaned Up
 * - First Release
 *
 * TODO (updated 04/27/2006)
 * -------------------------
 * 
 * 
 *************************************************************************************
 *
 *     This file is part of GeSHi.
 *
 *   GeSHi is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   GeSHi is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with GeSHi; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *

 ************************************************************************************/
$language_data = array (
	'LANG_NAME' => 'Text',
	'COMMENT_SINGLE' => array( ),
	'COMMENT_MULTI' => array( ),
	'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
	'QUOTEMARKS' => array(),
	'ESCAPE_CHAR' => '',
	'KEYWORDS' => array( ),
	'SYMBOLS' => array( ),
	'CASE_SENSITIVE' => array(
		GESHI_COMMENTS => false
		),
	'STYLES' => array(
		'KEYWORDS' => array(),
		'COMMENTS' => array(),
		'ESCAPE_CHAR' => array(),
		'BRACKETS' => array(),
		'STRINGS' => array(),
		'NUMBERS' => array(),
		'METHODS' => array(),
		'SYMBOLS' => array(),
		'SCRIPT' => array(),
		'REGEXPS' => array()
		),
	'OOLANG' => false,
	'OBJECT_SPLITTERS' => array(),
	'REGEXPS' => array(	),
	'STRICT_MODE_APPLIES' => GESHI_NEVER,
	'SCRIPT_DELIMITERS' => array( ),
	'HIGHLIGHT_STRICT_BLOCK' => array( )
);
if (is_a($this, 'GeSHi')) {
    $this->set_numbers_highlighting(false);
    $this->set_brackets_highlighting(false);
    $this->disable_highlighting();
}
?>

==> geshi_1.0.7.20.orig.tar.gz: geshi/geshi/text.php <==
<?php
/*************************************************************************************
 * text.php
 * --------
 * Author: Sean Hanna (smokingrope@gmail.com)
 * Copyright: (c) 2006 Sean Hanna 
 * Release Version: 1.0.7.20
 * Date Started: 04/23/2006
 *
 * Standard Text File (No Syntax Highlighting).
 *
 * CHANGES
 * -------
 * 04/23/2006 (0.5.0)
 *  -  Syntax File Created
 *
 * 04/27/2006 (1.0.0)
 * - Documentation Cleaned Up
 * - First Release
 *
 * TODO (updated 04/27/2006)
 * -------------------------
 * 
 * 
 *************************************************************************************
 *
 *     This file is part of GeSHi.
 *
 *   GeSHi is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   GeSHi is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with GeSHi; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *

 ************************************************************************************/
$language_data = array (
	'LANG_NAME' => 'Text',
	'COMMENT_SINGLE' => array( ),
	'COMMENT_MULTI' => array( ),
	'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
	'QUOTEMARKS' => array(),
	'ESCAPE_CHAR' => '',
	'KEYWORDS' => array( ),
	'SYMBOLS' => array( ),
	'CASE_SENSITIVE' => array(
		GESHI_COMMENTS => false
		),
	'STYLES' => array(
		'KEYWORDS' => array(),
		'COMMENTS' => array(),
		'ESCAPE_CHAR' => array(),
		'BRACKETS' => array(),
		'STRINGS' => array(),
		'NUMBERS' => array(),
		'METHODS' => array(),
		'SYMBOLS' => array(),
		'SCRIPT' => array(),
		'REGEXPS' => array()
		),
	'OOLANG' => false,
	'OBJECT_SPLITTERS' => array(),
	'REGEXPS' => array(	),
	'STRICT_MODE_APPLIES' => GESHI_NEVER,
	'SCRIPT_DELIMITERS' => array( ),
	'HIGHLIGHT_STRICT_BLOCK' => array( )
);
if (isset($this) && is_a($this, 'GeSHi')) {
    $this->set_numbers_highlighting(false);
    $this->set_brackets_highlighting(false);
    $this->disable_highlighting();
}
?>
